import { join } from "node:path";
import * as door43 from "../integrations/door43.js";
import * as ebible from "../integrations/ebible.js";
import * as dbl from "../integrations/dbl.js";
import { list_dirs, read_json } from "../parts/utils.js";
async function discover_translations(service, discover_specific_id) {
  const services = ["door43", "ebible", "dbl"];
  if (service && !services.includes(service)) {
    console.error(`Service must be one of: ` + services.join(", "));
    return;
  }
  const ids = Object.fromEntries(services.map(
    (service2) => [service2, []]
  ));
  for (const trans of list_dirs(join("sources", "bibles"))) {
    const meta = read_json(join("sources", "bibles", trans, "meta.json"));
    for (const service2 of Object.keys(meta.ids)) {
      ids[service2].push(meta.ids[service2]);
    }
  }
  if (!service || service === "dbl") {
    await dbl.discover(ids.dbl, discover_specific_id);
  }
  if (!service || service === "ebible") {
    await ebible.discover(ids.ebible, discover_specific_id);
  }
  if (service === "door43") {
    await door43.discover(ids.door43, discover_specific_id);
  }
}
export {
  discover_translations
};
//# sourceMappingURL=discover.js.map
