import fs from "node:fs";
import { join } from "node:path";
import { concurrent, read_json, type_from_path, read_dir_deep } from "../parts/utils.js";
import { PublisherAWS } from "../integrations/aws.js";
import { generate_index_content } from "../parts/indexes.js";
class Publisher extends PublisherAWS {
  // Interface for publishing collection to server
  async upload_file(path) {
    const server_path = path.slice("dist/".length);
    await this.upload(server_path, fs.readFileSync(path), type_from_path(path));
  }
  async upload_dir(dir) {
    const dir_contents = read_dir_deep(dir);
    await concurrent(dir_contents.files.map((path) => async () => {
      await this.upload_file(path);
    }));
    await concurrent(dir_contents.dirs.map((path) => async () => {
      const server_path = join(path.slice("dist/".length), "index.html");
      await this.upload(server_path, generate_index_content(path), "text/html");
    }));
  }
}
async function publish(type, id) {
  const publisher = new Publisher();
  const invalidations = [];
  if (!type || type === "bible") {
    invalidations.push(...await _publish_bible(publisher, id));
  }
  if (!type || type === "notes") {
    invalidations.push(...await _publish_notes(publisher, id));
  }
  if (!type || type === "data") {
    invalidations.push(...await _publish_data(publisher, id));
  }
  await publisher.upload("index.html", generate_index_content("dist"), "text/html");
  invalidations.push("/");
  await publisher.invalidate(invalidations);
}
async function _publish_bible(publisher, translation) {
  const manifest_path = join("dist", "bibles", "manifest.json");
  const manifest = read_json(manifest_path);
  const invalidations = [];
  for (const id in manifest.translations) {
    if (translation && id !== translation) {
      continue;
    }
    await publisher.upload_dir(join("dist", "bibles", id));
    invalidations.push(`/bibles/${id}/*`);
  }
  await publisher.upload_file(manifest_path);
  invalidations.push("/bibles/manifest.json");
  await publisher.upload("bibles/index.html", generate_index_content("dist/bibles"), "text/html");
  invalidations.push("/bibles/");
  return invalidations;
}
async function _publish_notes(publisher, id) {
  await publisher.upload_dir(join("dist", "notes"));
  return ["/notes/*"];
}
async function _publish_data(publisher, id) {
  await publisher.upload_dir(join("dist", "crossref"));
  return ["/crossref/*"];
}
export {
  Publisher,
  publish
};
//# sourceMappingURL=publish.js.map
