import http from "node:http";
import fs from "node:fs";
import { join } from "node:path";
import { type_from_path } from "../parts/utils.js";
import { generate_index_content } from "../parts/indexes.js";
async function serve(port = 8430) {
  const server = http.createServer((req, res) => {
    const time = (/* @__PURE__ */ new Date()).toLocaleTimeString();
    console.info(`[${time}] ${req.method} ${req.url}`);
    res.setHeader("Access-Control-Allow-Origin", "*");
    function send(status, contents) {
      res.writeHead(status);
      res.write(contents);
      res.end();
    }
    if (req.method !== "GET" || !req.url) {
      return send(400, "Request not supported");
    }
    let path = decodeURIComponent(req.url.split("?")[0]).slice(1);
    path = path ? join("dist", path) : "dist/";
    if (fs.existsSync(path)) {
      if (fs.statSync(path).isFile()) {
        res.setHeader("Content-Type", type_from_path(path));
        fs.createReadStream(path).pipe(res);
        return;
      }
      if (path.endsWith("/")) {
        res.setHeader("Content-Type", "text/html");
        return send(200, generate_index_content(path));
      }
    }
    return send(404, `Not found: ${req.url}`);
  });
  server.listen(port, () => {
    console.info(`Listening on http://localhost:${port}`);
  });
}
export {
  serve
};
//# sourceMappingURL=serve.js.map
