import { sep } from "node:path";
import { readFileSync } from "node:fs";
import { parse as parse_yaml } from "yaml";
import { S3 } from "@aws-sdk/client-s3";
import { CloudFront } from "@aws-sdk/client-cloudfront";
class PublisherAWS {
  _s3;
  _bucket;
  _cf;
  _cf_id;
  constructor() {
    const config = parse_yaml(readFileSync("config.yaml", "utf-8")).integrations.aws;
    this._s3 = new S3({ region: config.region });
    this._bucket = config.bucket;
    this._cf = new CloudFront({ region: config.region });
    this._cf_id = config.cloudfront;
  }
  async upload(key, body, type) {
    await this._s3.putObject({
      Bucket: this._bucket,
      Key: key.replaceAll(sep, "/"),
      Body: body,
      ContentType: type
    });
  }
  async invalidate(paths) {
    if (paths.length > 100) {
      paths = ["/*"];
    }
    await this._cf.createInvalidation({ DistributionId: this._cf_id, InvalidationBatch: {
      CallerReference: (/* @__PURE__ */ new Date()).getTime().toString(),
      Paths: {
        Quantity: paths.length,
        Items: paths
      }
    } });
  }
}
export {
  PublisherAWS
};
//# sourceMappingURL=aws.js.map
