interface MultiVerseNote {
    start_c: number;
    start_v: number;
    end_c: number;
    end_v: number;
    contents: string;
}
export interface StudyNotes {
    verses: Record<string, Record<string, string>>;
    ranges: MultiVerseNote[];
}
export declare function get_notes(id: string): Record<string, StudyNotes> | null;
/**
 * Extract study notes from Tyndale XML and convert to standard HTML/JSON
 * Source: StudyNotes.xml from https://tyndaleopenresources.com/
 *
 * @param xml The XML to parse
 *
 * @returns The data to be converted to JSON
 */
export declare function study_notes_to_json(xml: string): Record<string, StudyNotes>;
/**
 * An interface describing the extracted Bible reference
 */
export interface TyndaleBibleReference {
    book: string;
    usx: string;
    start_chapter: number;
    start_verse: number;
    end_chapter: number;
    end_verse: number;
    is_range: boolean;
}
/**
 * Extract the scripture reference based on Tyndale format
 *
 * @param reference The reference string
 *
 * @returns The extracted verse details
 */
export declare function extract_reference(reference: string): TyndaleBibleReference | null;
/**
 * Extract the body of the note and transform it to align with our requirements.
 *
 * @param body The body of the note
 *
 * @returns The transformed text
 */
export declare function clean_note(body: string): string;
/**
 * Some times Tyndale uses an alternative book name for books.
 * (ie. 1Kgs instead of IKgs).  This list allows us to look up
 * the tyndale based on the alternative.
 */
export declare const refs_to_tyndale: Record<string, string>;
export declare const tyndale_to_usx_book: Record<string, string>;
export {};
