import { join } from "node:path";
import { convert as html_to_text } from "html-to-text";
import * as tyndale from "../integrations/tyndale.js";
import { clean_dir, list_dirs, mkdir_exist, read_json, write_json } from "../parts/utils.js";
function notes_process() {
  clean_dir(join("dist", "notes"));
  const manifest = { notes: {} };
  for (const id of list_dirs(join("sources", "notes"))) {
    const notes = tyndale.get_notes(id);
    if (notes) {
      const html_dir = join("dist", "notes", id, "html");
      const txt_dir = join("dist", "notes", id, "txt");
      mkdir_exist(html_dir);
      mkdir_exist(txt_dir);
      for (const book of Object.keys(notes)) {
        write_json(join(html_dir, `${book}.json`), notes[book]);
        write_json(join(txt_dir, `${book}.json`), notes_to_txt(notes[book]));
      }
      const meta = read_json(join("sources", "notes", id, "meta.json"));
      manifest.notes[id] = {
        ...meta,
        year: meta.year ?? (/* @__PURE__ */ new Date()).getFullYear(),
        books: Object.keys(notes)
      };
    }
  }
  write_json(join("dist", "notes", "manifest.json"), manifest);
}
function notes_to_txt(notes) {
  const plain = { verses: {}, ranges: [] };
  for (const range of notes.ranges) {
    plain.ranges.push({
      ...range,
      contents: html_to_text(range.contents, { wordwrap: false })
    });
  }
  for (const ch in notes.verses) {
    plain.verses[ch] = {};
    for (const verse in notes.verses[ch]) {
      plain.verses[ch][verse] = html_to_text(notes.verses[ch][verse], { wordwrap: false });
    }
  }
  return plain;
}
export {
  notes_process
};
//# sourceMappingURL=notes.js.map
