import { PassageReference } from "@gracious.tech/bible-references";
function extract_sections(json_txt) {
  const sections = [];
  for (let ch = 1; ch < json_txt.contents.length; ch++) {
    for (let v = 1; v < json_txt.contents[ch].length; v++) {
      for (const item of json_txt.contents[ch][v]) {
        if (typeof item === "string" || item.type !== "heading") {
          continue;
        }
        if (item.level === 3) {
          continue;
        }
        let previous = sections.at(-1);
        if (previous?.start_chapter === ch && previous?.start_verse === v) {
          sections.pop();
          previous = sections.at(-1);
        }
        if (previous) {
          const prev_verse = new PassageReference(json_txt.book, ch, v).get_prev_verse();
          previous.end_chapter = prev_verse.start_chapter;
          previous.end_verse = prev_verse.start_verse;
        }
        sections.push({
          start_chapter: ch,
          start_verse: v,
          end_chapter: ch,
          end_verse: v,
          heading: item.contents
        });
      }
    }
  }
  if (sections.length) {
    sections[0].start_chapter = 1;
    sections[0].start_verse = 1;
    sections.at(-1).end_chapter = json_txt.contents.length - 1;
    sections.at(-1).end_verse = json_txt.contents.at(-1).length - 1;
  }
  return sections;
}
function generate_chapter_headings(json_txt, sections) {
  const chapters = new Array(json_txt.contents.length).fill("");
  for (const section of sections) {
    if (section.start_verse === 1) {
      chapters[section.start_chapter] = section.heading;
      section.heading = null;
    } else if (section.end_chapter !== section.start_chapter) {
      chapters[section.start_chapter + 1] = section.heading;
    }
  }
  for (let ch = 1; ch < json_txt.contents.length; ch++) {
    if (!chapters[ch]) {
      const v1 = json_txt.contents[ch][1];
      const v1_str = v1.filter((part) => typeof part === "string").join("");
      const v1_trimmed = v1_str.slice(0, 50);
      const last_space = v1_trimmed.lastIndexOf(" ");
      chapters[ch] = v1_trimmed.slice(0, last_space) + "\u2026";
    }
  }
  return chapters;
}
export {
  extract_sections,
  generate_chapter_headings
};
//# sourceMappingURL=sections.js.map
