/**
 * An interface for directory entries
 */
export interface DirectoryEntry {
    isDirectory: boolean;
    name: string;
    fileSize: number | undefined;
    dirSize: number | undefined;
}
export declare function request<T>(url: string, type?: 'json'): Promise<T>;
export declare function request(url: string, type: 'text'): Promise<string>;
export declare function request(url: string, type: 'blob'): Promise<Blob>;
export declare function request(url: string, type: 'arrayBuffer'): Promise<ArrayBuffer>;
export declare function concurrent(tasks: (() => Promise<unknown>)[], limit?: number): Promise<void>;
export declare function mkdir_exist(path: string): void;
export declare function clean_dir(path: string): void;
/**
 * Read the directory and pass back the names of the entries. This is a wrapper to ignore
 * specific files.
 *
 * @param path The path to read
 *
 * @returns The entry names
 */
export declare function read_dir(path: string): string[];
/**
 * Get directory entries for a given path
 *
 * @param path The path to read
 *
 * @returns The directory entries
 */
export declare function get_dir_entries(path: string): DirectoryEntry[];
export declare function list_files(directory: string): string[];
export declare function list_dirs(directory: string): string[];
export declare function read_dir_deep(directory: string): {
    dirs: string[];
    files: string[];
};
export declare function read_json<T>(path: string): T;
export declare function write_json(path: string, data: unknown, indented?: boolean): void;
export declare const PKG_PATH: string;
export declare function type_from_path(path: string): "application/xml" | "text/plain" | "text/html" | "application/json" | "application/octet-stream";
